[![Rye](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/rye/main/artwork/badge.json)](https://rye.astral.sh)
[![GPL](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://github.com/galenseilis/PPPModels/blob/main/LICENSE)
[![Open Source Love](https://badges.frapsoft.com/os/v1/open-source.png?v=103)](https://github.com/ellerbrock/open-source-badges/)

# PPPModels
Package for making predictions with Poisson point processes.
